---
title: 拦截过滤会话
---

IMKit SDK 支持过滤会话列表中的数据，由应用程序决定是否展示部分会话。

:::tip

 过滤会话设置需要在 IMKit 初始化时传入，设置此回调后会影响会话列表展示数据，请慎重设置。
:::


在 IMKit SDK 的 `init` 方法中添加 `customIntercept`，接收会话信息并返回该会话是否需要在会话列表中展示。

```js
// 如已引入可忽略
import { ConversationType } from '@rongcloud/imlib-next'

// 代码示例中展示过滤掉系统类型会话，使用时可根据您的需要按需过滤，过滤后不会在会话列表中展示，请知晓！！！
const customIntercept = {
  // 过滤会话 false / true
  interceptConversation: conversation => {
    if (!conversation) return true;

    //  匹配过滤 - 系统会话
    if (conversation.conversationType === ConversationType.SYSTEM) {
      return true; // 返回 true 为不展示该会话
    }

    // 正常会话 - 不过滤
    return false;// 返回 false 正常展示
  }
};

/** 特别注意：
 * 1. 设置此回调后会影响会话列表展示数据，请慎重设置。
 * 2. 此处 init 仅为展示自定义消息设置，应用内不需要多次进行初始化
 */
imkit.init({
  customIntercept:customIntercept
});
```
